﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace DataAPI.Models
{
    public class DTCInfo
    {
        /// <summary>Unique auto-incrementing row identifier</summary>
        public int Id { get; set; }
        /// <summary>Coordinated Universal Time of the data row</summary>
        public DateTime UTCDate { get; set; }
        /// <summary>Device Identifier of the data communication device. (Embossed on the case as "Serial #")</summary>
        public int DevId { get; set; }
        /// <summary>GPS course over ground in degrees (0-359)</summary>
        public int COG { get; set; }
        /// <summary>GPS latitude in decimal degrees</summary>
        public double Lat { get; set; }
        /// <summary>GPS longitude in decimal degrees</summary>
        public double Lon { get; set; }
        /// <summary>Diagnostic Code is OBDii bus. When true, OBDCode applies, otherwise JBusXXX applies</summary>
        public bool CodeIsOBD { get; set; }
        /// <summary>this diagnostic code has cleared</summary>
        public bool CodeClr { get; set; }
        /// <summary>OBDii diagnostic code string when CodeIsOBD is true, otherwise null</summary>
        public string OBDCode { get; set; }
        /// <summary>OBDii ECU that caused the code when CodeIsOBD is true, otherwise null</summary>
        public int OBDecu { get; set; }
        /// <summary>JBus Suspect Parameter Number (SPN) when CodeIsOBD is false, otherwise null</summary>
        public int JBusSPN { get; set; }
        /// <summary>JBus Failure Mode Identifier (FMI) when CodeIsOBD is false, otherwise null</summary>
        public int JBusFMI { get; set; }
        /// <summary>JBus Occurrence Count when CodeIsOBD is false, otherwise null</summary>
        public int JBusOCC { get; set; }
        /// <summary>For J1587 vehices, LampBits should be ignored. 
        /// For OBDii vehicles LampBits will be 1 when engine lamp is on. 
        /// For J1939 vehicles, LampBits is bits 4 and 5 Red Lamp Status, bits 2 and 3 Amber Lamp status, 
        /// bits 0 and 1 Protect Lamp Staus, bits 6 and 7 Malfunction Indicator</summary>
        public int LampBits { get; set; }
    }
}