﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace DataAPI.Models
{
    /// <summary>Seat Belt switch states</summary>
    public enum BeltSwitchType { NotBuckled, Buckled, Error, NotAvailable };
    /// <summary>Parking Brake switch states</summary>
    public enum PBSwitchType { NotSet, Set, Error, NotAvailable };

    public class ECMInfo
    {
        /// <summary>Unique auto-incrementing row identifier</summary>
        public int Id { get; set; }
        /// <summary>Coordinated Universal Time of the data row</summary>
        public DateTime UTCDate { get; set; }
        /// <summary>Device Identifier of the data communication device. (Embossed on the case as "Serial #")</summary>
        public int DevId { get; set; }
        /// <summary>GPS vehicle speed over ground in km/h</summary>
        public int SOG { get; set; }
        /// <summary>GPS course over ground in degrees (0-359)</summary>
        public int COG { get; set; }
        /// <summary>GPS latitude in decimal degrees</summary>
        public double Lat { get; set; }
        /// <summary>GPS Longitude in decimal degrees</summary>
        public double Lon { get; set; }
        /// <summary>number of hard braking events in the past minute.  Defined has a descrease in speed of greater than or equal to 11 km/h per second</summary>
        public int HardBrake { get; set; }
        /// <summary>when true RPM is provided by the ECM</summary>
        public bool ValRPM { get; set; }
        /// <summary>average RPM reading over the past minute</summary>
        public double AvgRPM { get; set; }
        /// <summary>minimum RPM reading for the past minute</summary>
        public double MinRPM { get; set; }
        /// <summary>maximum RPM reading for the past minute</summary>
        public double MaxRPM { get; set; }
        /// <summary>when true vehicle speed is provided by the ECM</summary>
        public bool ValSpd { get; set; }
        /// <summary>average vehicle speed in km/h over the past minute</summary>
        public double AvgSpd { get; set; }
        /// <summary>minimum vehicle speed in km/h for the past minute</summary>
        public double MinSpd { get; set; }
        /// <summary>maximum vehicle speed in km/h for the past minute</summary>
        public double MaxSpd { get; set; }
        /// <summary>when true engine coolant temperature is provided by the ECM</summary>
        public bool ValCool { get; set; }
        /// <summary>average engine coolant temperature in degrees C over the past minute</summary>
        public double AvgCool { get; set; }
        /// <summary>mimimum engine coolant temperature in degrees C over the past minute</summary>
        public double MinCool { get; set; }
        /// <summary>maximum engine coolant temperature in degrees C over the past minute</summary>
        public double MaxCool { get; set; }
        /// <summary>when true engine oil pressure is provided by the ECM</summary>
        public bool ValOilP { get; set; }
        /// <summary>average oil pressure in PSI over the past minute</summary>
        public double AvgOilP { get; set; }
        /// <summary>mimimum oil pressure in PSI over the past minute</summary>
        public double MinOilP { get; set; }
        /// <summary>maximum oil pressure in PSI over the past minute</summary>
        public double MaxOilP { get; set; }
        /// <summary>fuel used in litres over the past minute</summary>
        public double FuelUsed { get; set; }
        /// <summary>when true engine hours are provided by the ECM</summary>
        public bool ValHrs { get; set; }
        /// <summary>total engine hours</summary>
        public double EngHrs { get; set; }
        /// <summary>when true an odometer value is provided by the ECM</summary>
        public bool ValOdom { get; set; }
        /// <summary>odometer value in km</summary>
        public double Odom { get; set; }
        /// <summary>Idle time in seconds over the past minute</summary>
        public double IdleTim { get; set; }
        /// <summary>seat belt switch status (see BeltSwitchType Enum)</summary>
        public BeltSwitchType BeltSwitch { get; set; }
        /// <summary>parking brake switch status (see PBSwitchType Enum)</summary>
        public PBSwitchType PBSwitch { get; set; }
    }
}