﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace DataAPI.Models
{
    /// <summary>
    /// VehicleInfo Data Class
    /// </summary>
    public class VehicleInfo
    {
        /// <summary>Unique auto-incrementing row identifier</summary>
        public int Id { get; set; }
        /// <summary>When true, this flag indicates that the row is spreader data, when false, the row is GPS data</summary>
        public bool spData { get; set; }
        /// <summary>Coordinated Universal Time of the data row</summary>
        public DateTime UTCDate { get; set; }
        /// <summary>Device Identifier of the data communication device. (Embossed on the case as "Serial #")</summary>
        public int DevId { get; set; }
        /// <summary>GPS vehicle speed over ground in km/h</summary>
        public int SOG { get; set; }
        /// <summary>GPS course over ground in degrees (0-359)</summary>
        public int COG { get; set; }
        /// <summary>GPS latitude in decimal degrees</summary>
        public double Lat { get; set; }
        /// <summary>GPS Longitude in decimal degrees</summary>
        public double Lon { get; set; }
        /// <summary>The incremental change (delta) in total spreading distance represented in kilometres.
        /// A sum() of this column will result in total spreading distance for the period.
        /// Note: This value is derived from the spreader controller, NOT the GPS.</summary>
        public double Dist { get; set; }
        /// <summary>The incremental change (delta) in liquid only (DLA) spreading distance represented in kilometres.
        /// A sum() of this column will result in total spreading distance of liquid only (DLA) for the period.
        /// Note: This value is derived from the spreader controller, NOT the GPS.</summary>
        public double DistLiq { get; set; }
        /// <summary>The incremental change (delta) in dry material 1 spreading distance represented in kilometres.
        /// A sum() of this column will result in total spreading distance of dry material 1 for the period.
        /// Note: This value is derived from the spreader controller, NOT the GPS.</summary>
        public double DistMat1 { get; set; }
        /// <summary>The incremental change (delta) in dry material 2 spreading distance represented in kilometres.
        /// A sum() of this column will result in total spreading distance of dry material 2 for the period.
        /// Note: This value is derived from the spreader controller, NOT the GPS.</summary>
        public double DistMat2 { get; set; }
        /// <summary>The incremental change (delta) in distance represented in metres.
        /// A sum of this column will result in total distance in metre's for the period.
        /// Note: This value is derived from the GPS.</summary>
        public double Odom { get; set; }
        /// <summary>Indicates the spreader controller is applying dry material (normally salt or sand)</summary>
        public bool DryOn { get; set; }
        /// <summary>Indicates the spreader controller is applying direct liquid application material.</summary>
        public bool LiqOn { get; set; }
        /// <summary>Indicates the spreader controller is applying pre-wet material</summary>
        public bool PWOn { get; set; }
        /// <summary>The incremental difference in dry material (salt/sand) applied represented in kilograms</summary>
        public double DryAmt { get; set; }
        /// <summary>The incremental difference in dry material #1 applied represented in kilograms</summary>
        public double DryAmtMat1 { get; set; }
        /// <summary>The incremental difference in dry material #2 applied represented in kilograms</summary>
        public double DryAmtMat2 { get; set; }
        /// <summary>The incremental differine in liquid material (DLA) applied represented in litres</summary>
        public double LiqAmt { get; set; }
        /// <summary>The incremental difference in prewet material applied represented in litres</summary>
        public double PWAmt { get; set; }
        /// <summary>The incremental difference in blast dry material (salt/sand) applied repfresented in kilograms</summary>
        public double BlastDryAmt { get; set; }
        /// <summary>The incremental difference in blast liquid material applied represented in litres</summary>
        public double BlastLiqAmt { get; set; }
        /// <summary>Current alarm code.  The list of codes are per spreader type TBD.</summary>
        public int Alarm { get; set; }
        /// <summary>True if temperature values below are valid otherwise ignore AirTemp and SurfTemp.</summary>
        public bool TempVal { get; set; }
        /// <summary>Air temperature in degrees C only if TempVal is true</summary>
        public double AirTemp { get; set; }
        /// <summary>Surface or road temperature in degrees C only if TempVal is true</summary>
        public double SurfTemp { get; set; }
        /// <summary>True if plow blade is down (on the surface)</summary>
        public bool Plow { get; set; }
        /// <summary>True if wing blade is down</summary>
        public bool Wing { get; set; }
        /// <summary>True if tow plow blade is down</summary>
        public bool Tow { get; set; }
        /// <summary>Spreader Type where:
        /// 0 = Epoke
        /// 1 = CS230
        /// 2 = CS440
        /// 3 = Schmidt
        /// 4 = Dickie John
        /// 5 = ACE
        /// 6 = Force America
        /// 7 = Parker
        /// 8 = DMT</summary>
        public int spType { get; set; }
        /// <summary>Rate of salt/sand represented in kgs / lane kilometre</summary>
        public double DryRate { get; set; }
        /// <summary>Rate of prewet in litres / tonne or rate of DLA in litres / lane kilometre (see RateMode below)</summary>
        public double WetRate { get; set; }
        /// <summary>0 = not spreading, 1 = spreading dry (salt/sand) material, 2 = spreading dry material with prewet, 3 = spreading liquid only (DLA)</summary>
        public int RateMode { get; set; }
    }
}