﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Newtonsoft.Json.Linq;

namespace DataAPIClient
{
    public partial class frmMain : Form
    {
        public frmMain()
        {
            InitializeComponent();
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            // load current settings
            txtUrl.Text = Properties.Settings.Default.txtUrl;
            txtAuth.Text = Properties.Settings.Default.txtAuth;
        }

        private void btnTestVehicleInfoAPI_Click(object sender, EventArgs e)
        {
            using (frmTestVehicleInfo frm = new frmTestVehicleInfo())
            {
                frm.TestURL = this.txtUrl.Text;
                frm.TestAuth = this.txtAuth.Text;
                frm.ShowDialog();
            }
        }

        private void btnTestECMInfo_Click(object sender, EventArgs e)
        {
            using (frmTestECMInfo frm = new frmTestECMInfo())
            {
                frm.TestURL = this.txtUrl.Text;
                frm.TestAuth = this.txtAuth.Text;
                frm.ShowDialog();
            }
        }

        private void btnTestDTCInfo_Click(object sender, EventArgs e)
        {
            using (frmTestDTCInfo frm = new frmTestDTCInfo())
            {
                frm.TestURL = this.txtUrl.Text;
                frm.TestAuth = this.txtAuth.Text;
                frm.ShowDialog();
            }
        }

        private void frmMain_FormClosing(object sender, FormClosingEventArgs e)
        {
            // makes like easier if we save these values.  Restored in form_load()
            Properties.Settings.Default.txtUrl = txtUrl.Text;
            Properties.Settings.Default.txtAuth = txtAuth.Text;
            Properties.Settings.Default.Save();
        }

        /// <summary>
        /// enable/disable controls in a panel
        /// </summary>
        /// <param name="panel">panel for which controls enable property will be changed</param>
        /// <param name="enable">true enables, false disables</param>
        public static void EnableControls(Panel panel, bool enable)
        {
            // iterate the control list for the panel
            foreach (Control c in panel.Controls)
            {
                if (c is GroupBox)
                {
                    foreach (Control g in c.Controls)
                        if (g.Visible && g.ForeColor != Color.Red)
                            g.Enabled = enable;
                }
                else
                    if (c.Visible && c.ForeColor != Color.Red)
                        c.Enabled = enable;
            }
        }

        /// <summary>
        /// trim and add a trailing forward slash if required
        /// </summary>
        /// <param name="uri">uri to fix up</param>
        /// <returns>uri with the trailing slash</returns>
        public static string FixUri(string uri)
        {
            string Result = uri.TrimEnd();
            if (!Result.EndsWith("/"))
                Result += "/";
            return Result;
        }

        /// <summary>
        /// simple helper method simulates the C atoi() function
        /// </summary>
        /// <param name="s">string to convert to a Int32</param>
        /// <returns>returns Int32 value else zero if exception</returns>
        public static int atoi(string s)
        {
            int Result = 0;
            try
            {
                Result = Convert.ToInt32(s);
            }
            catch { }
            return Result;
        }

    }

    /// <summary>
    /// provides an extension to check JToken for null or empty
    /// </summary>
    public static class JsonExtensions
    {
        public static bool IsNullOrEmpty(this JToken token)
        {
            return (token == null) ||
                   (token.Type == JTokenType.Array && !token.HasValues) ||
                   (token.Type == JTokenType.Object && !token.HasValues) ||
                   (token.Type == JTokenType.String && token.ToString() == String.Empty) ||
                   (token.Type == JTokenType.Null);
        }
    }
}
