﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Net;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Json;
using System.Web;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using System.Net.Http;
using DataAPI.Models;

namespace DataAPIClient
{
    public partial class frmTestVehicleInfo : Form
    {
        public string TestURL;
        public string TestAuth;

        // exit out of the get loop when tru
        private bool AbortFlag = false;
        const string LONG_DATE_STRING = "yyyy-MM-dd HH:mm:ss";
        const string ISO_DATE_STRING = "yyyy-MM-ddTHH:mm:ssZ";
        public frmTestVehicleInfo()
        {
            InitializeComponent();
        }

        /// <summary>
        /// return a ListViewItem 
        /// </summary>
        /// <param name="v">VehincleInfo object filled via the web service</param>
        /// <returns>new ListViewItem with VechicleInfo in the correct columns</returns>
        private ListViewItem VehicleListViewItem(VehicleInfo v)
        {
            ListViewItem lvi = new ListViewItem(v.Id.ToString());
            lvi.SubItems.Add(v.spData ? "yes" : "no");
            lvi.SubItems.Add(v.UTCDate.ToString(LONG_DATE_STRING));
            lvi.SubItems.Add(v.DevId.ToString());
            lvi.SubItems.Add(v.Lat.ToString("N6"));
            lvi.SubItems.Add(v.Lon.ToString("N6"));
            lvi.Tag = v;        // save for later reference
            return lvi;
        }

        /// <summary>
        /// do most of the work in here
        /// perform the Get and deserialize the JSon results into a VehicleInfo array
        /// </summary>
        /// <param name="requestString">the Get request string</param>
        /// <returns>VehicleInfo array</returns>
        private VehicleInfo[] PerformVehicleInfoGet(string requestString)
        {
            VehicleInfo[] Response = new VehicleInfo[0];
            Uri baseUri = new Uri(frmMain.FixUri(TestURL));
            // combine the uri's
            Uri requestUri = new Uri(baseUri, requestString);
            // and make a web request
            HttpWebRequest vehicleInfoRequest = (HttpWebRequest)WebRequest.Create(requestUri);
            // authorization, looks up 
            vehicleInfoRequest.Headers.Add("Authorization", Uri.EscapeDataString(TestAuth));
            vehicleInfoRequest.Method = "Get";
            // actually perform the Get
            WebResponse vehicleInfoResponse = vehicleInfoRequest.GetResponse();
            using (vehicleInfoResponse)
            {
                // convert the Json stream to JArray then to VehicleInfo array
                using (Stream stream = (Stream)vehicleInfoResponse.GetResponseStream())
                {
                    string jsonString = new StreamReader(stream).ReadToEnd();
                    JArray jarray = JArray.Parse(jsonString);
                    // is it the end?
                    if (jarray.IsNullOrEmpty())
                        Response = null;
                    else
                        Response = jarray.ToObject<VehicleInfo[]>();
                }
                // make sure it's valid
                if (Response != null)
                {
                    // if we've got something, then fill the ListView
                    foreach (VehicleInfo v in Response)
                        lstView.Items.Add(VehicleListViewItem(v));
                }
            }
            return Response;

        }

        /// <summary>
        /// demonstrates the GetById method of the Restful ROADA API
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnGetResultsById_Click(object sender, EventArgs e)
        {
            // disable the controls in the top panel while processing
            frmMain.EnableControls(splitContainer1.Panel1, false);
            try
            {
                // start by clearing out the old
                lstView.Items.Clear();

                int startId = frmMain.atoi(txtStartId.Text);
                VehicleInfo[] Response = null;
                // allows exit from the loop via abort button
                AbortFlag = false;
                btnAbortByRowId.Visible = true;
                do
                {
                    // show a status
                    stsLabel.Text = string.Format("Reading Id: {0}", startId);
                    Application.DoEvents();
                    Response = null;
                    // create the Get string
                    string requestString = string.Format("api/vehicleinfo?startid={0}&maxrows={1}", startId, txtMaxRowsById.Text);
                    // execute the get
                    Response = PerformVehicleInfoGet(requestString);
                    // do we have anything?
                    if (Response != null)
                    {
                        // get the next id number to query
                        if (Response.Length > 0)
                            startId = Response[Response.Length - 1].Id;
                        Application.DoEvents();
                    }
                } while (Response != null && Response.Length > 0 && ! AbortFlag);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
            finally
            {
                stsLabel.Text = "Idle";
                // renable the controls in the top panel
                frmMain.EnableControls(splitContainer1.Panel1, true);
                btnAbortByRowId.Visible = false;
            }
        }

        /// <summary>
        /// demonstrates the GetByDate and device id of the Restful ROADA API
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnGetResultsByDate_Click(object sender, EventArgs e)
        {
            // disable the controls in the top panel while processing
            frmMain.EnableControls(splitContainer1.Panel1, false);
            try
            {
                // start by clearing out the old
                lstView.Items.Clear();

                // create the start/end date from the 2 DateTimePickers
                DateTime startDate = dtpDateStart.Value.Date + dtpTimeStart.Value.TimeOfDay;
                DateTime endDate = dtpDateEnd.Value.Date + dtpTimeEnd.Value.TimeOfDay;
                VehicleInfo[] Response = null;
                // allows exit from the loop via abort button
                AbortFlag = false;
                btnAbortByDate.Visible = true;
                do
                {
                    // show a status
                    stsLabel.Text = string.Format("Reading Date: {0}", startDate.ToString(LONG_DATE_STRING));
                    Application.DoEvents();
                    Response = null;
                    // create the Get string
                    // int devId, DateTime startDate, DateTime endDate, int maxRows
                    string requestString = string.Format("api/vehicleinfo?devid={0}&startdate={1}&enddate={2}&maxrows={3}",
                        txtDevId.Text, startDate.ToString(ISO_DATE_STRING), endDate.ToString(ISO_DATE_STRING), txtMaxRowsById.Text);
                    // execute the get
                    Response = PerformVehicleInfoGet(requestString);
                    // do we have anything?
                    if (Response != null)
                    {
                        // get the next id number to query
                        if (Response.Length > 0)
                            startDate = Response[Response.Length - 1].UTCDate;
                        Application.DoEvents();
                    }
                } while (Response != null && Response.Length > 0 && !AbortFlag);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
            finally
            {
                stsLabel.Text = "Idle";
                // renable the controls in the top panel
                frmMain.EnableControls(splitContainer1.Panel1, true);
                btnAbortByDate.Visible = false;
            }
        }

        /// <summary>
        /// set the abort flag so that the Get can abort
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnAbortByRowId_Click(object sender, EventArgs e)
        {
            // set a flag to get out of the "get" loop
            AbortFlag = true;
        }

        /// <summary>
        /// allows a context menu or double click to display this rows position on Google Maps in a browser window
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void showOnMapToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (lstView.SelectedIndices.Count > 0)
            {
                // the filled vehicleinfo was saved in the tag by VehicleListViewItem() above
                VehicleInfo v = (VehicleInfo)lstView.SelectedItems[0].Tag;
                string launchString = string.Format(@"http://maps.google.com/maps?z=6&t=m&q=loc:{0}+{1}", v.Lat, v.Lon);
                System.Diagnostics.Process.Start(launchString);
            }
        }

        private void frmTestVehicleInfo_Load(object sender, EventArgs e)
        {
            // default some of the controls to descent values
            dtpDateStart.Value = DateTime.UtcNow.AddDays(-1);
            dtpTimeStart.Value = DateTime.UtcNow.Date;
            dtpDateEnd.Value = DateTime.UtcNow;
            dtpTimeEnd.Value = DateTime.UtcNow;
        }

    }
}
